#!/usr/local/bin/perl -w

#### LAST UPDATED: Nov16, 2002 ####
# filter3.pl version 0.1

###########################################################################
#
# This program removes the character references within the context of INPUT 
# file. The character refernces which may be helpful in correct part of 
# speech tagging are converted to appropriate symbols while the others are
# eliminated. The output is placed in the DESTINATION file.
# The data which is filtered out is placed in the FILTER file.
#
# USAGE :  filter3.pl [OPTIONS] FILTER DESTINATION SOURCE
#
###########################################################################

# Copyright (C) 2000-2002
# Ted Pedersen, University of Minnesota, Duluth
# tpederse@d.umn.edu
# Mohammad Saif, University of Minnesota, Duluth
# moha0149@d.umn.edu
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# START OF PROGRAM
use Getopt::Long;

# Check if any options specified
GetOptions("version", "help");
if ( defined $opt_help )    { $help = $opt_help; }
else                        { $help = 0; }
# Print help if asked
if ( $help ) {
    &help();
    exit; }
# if version has been requested, show version
if ( defined $opt_version )
{
    $opt_version = 1;
    &showVersion();
    exit;
}

# Check if command line options have been provided
# If not print usage information
if ( $#ARGV < 2 ) {
    &usage();
    exit; }

$filter = shift();
$opfl = shift();
$inpfl = shift();

if(-f $opfl) {  
    print "Destination file already exists. Press `y' to overwrite\n";
    $resp = <STDIN>;
    chomp($resp);
    if($resp eq "y" || $resp eq "Y") {
	print "Overwriting the file.\n"; }
    else {
	exit; } } 

if(-f $filter) { 
    print "Filter file already exists. Press `y' to overwrite\n";
    $resp = <STDIN>;
    chomp($resp);
    if($resp eq "y" || $resp eq "Y") {
        print "Overwriting the file.\n"; }
    else {
        exit; } } 

# Open appropriate files
open(INP,"<$inpfl");
open(DB,">$filter");
open(OP,">$opfl");

# Read data from input file - line by line
while($ln = <INP>) {
	if($ln =~ /^\s*$/) {
	next; }

	# Replace character references by appropriate symbols
	# --, -, ", &, <, >, ', [, ], {, }, #
	# These characters are tokenized as well
	while($ln =~ /&mdash;/g){
                $ln =~ s/&mdash;/ -- /g;}
	while($ln =~ /&ndash;/g){
                $ln =~ s/&ndash;/ - /g;}
	while($ln =~ /&([be]|[lr]d)?quo;/g){
                $ln =~ s/&([be]|[lr]d)?quo;/ " /g;}
	while($ln =~ /&amp;/g){
                $ln =~ s/&amp;/ & /g;}
        while($ln =~ /&lt;/g){
                $ln =~ s/&lt;/ < /g;}
	while($ln =~ /&gt;/g){
                $ln =~ s/&gt;/ > /g;}
        while($ln =~ /&apos;/g){
                $ln =~ s/&apos;/ ' /g;}
        while($ln =~ /&lsquo;/g){
                $ln =~ s/&lsquo;/ ` /g;}
	while($ln =~ /&rsquo;/g){
                $ln =~ s/&rsquo;/ ' /g;}
        while($ln =~ /&lsqb;/g){
                $ln =~ s/&lsqb;/ [ /g;}
        while($ln =~ /&rsqb;/g){
                $ln =~ s/&rsqb;/ ] /g;}
        while($ln =~ /&num;/g){
                $ln =~ s/&num;/ \# /g;}
	while($ln =~ /&lcub;/g){
                $ln =~ s/&lcub;/ \{ /g;}
	while($ln =~ /&rcub;/g){
                $ln =~ s/&rcub;/ \} /g;}
	# Jul16
 	while($ln =~ /&\s*equals\s*;/g){
                $ln =~ s/&\s*equals\s*;/ = /g;}

	# Eliminate all remaining character references
	while($ln =~ /&([^&;\.\s]*)[;\.]/g) {
		# Write character reference to filter file
		print DB "$1\n";
		# Replace character references by space
		$ln =~ s/(&[^&;\.\s]*[;\.])/ /g; }

	print OP $ln; }

# Subroutine to print help message
sub help {
    print "Usage: filter3.pl [OPTIONS] FILTER DESTINATION SOURCE\n\n"; 
    print "This program removes the character references within the context of INPUT file. The character refernces which may be helpful in correct part of speech tagging are converted to appropriate symbols while the others are eliminated. The output is placed in the DESTINATION file. The data which is filtered out is placed in the FILTER file.\n";
    print "OPTIONS:\n\n";
    print "  --help             Prints the help message.\n"; 
    print "  --version          Prints the version number.\n\n"; }

sub usage {
    print "Usage: filter3.pl [OPTIONS] FILTER DESTINATION SOURCE\n"; 
    AskHelp(); }
# Message describing way to get help
sub AskHelp {
    print "Type filter3.pl --help for help.\n"; }
# function to output the version number
sub showVersion
{
    print STDERR "filter3.pl      -        version 0.1\n";
    print STDERR "A component of posSenseval version 0.1\n";
    print STDERR "Copyright (C) 2000-2003, Saif Mohammad Ted Pedersen\n";
}

