#!/usr/local/bin/perl -w

#### LAST UPDATED: Oct19, 2002 ####
# xml.pl Version 0.1

###########################################################################
#
# This program checks if any non-contextual data in the form of xml tags 
# still exists in the file(SOURCE). It prints all tokens within angular
# braces into the DESTINATION file.
# Ideally it should be blank for tagging purposes.
#
# USAGE : xml.pl DESTINATION SOURCE 
#
###########################################################################

# Copyright (C) 2000-2002
# Ted Pedersen, University of Minnesota, Duluth
# tpederse@d.umn.edu
# Mohammad Saif, University of Minnesota, Duluth
# moha0149@d.umn.edu
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# START OF PROGRAM
use Getopt::Long;

# Check if any options specified
GetOptions("version", "help");
if ( defined $opt_help )    { $help = $opt_help; }
else                        { $help = 0; }
# Print help if asked
if ( $help )
{
    &help();
    exit;
}
# if version has been requested, show version
if ( defined $opt_version )
{
    $opt_version = 1;
    &showVersion();
    exit;
}

# check if command line options have been provided
# If not print usage information
if ( $#ARGV < 1 )
{
    &usage();
    exit;
}

# Accept Source file name
$chktokfl = shift(@ARGV);
$inptagd = shift(@ARGV);

if(-e $chktokfl)
{
    print "Destination file already exists. Press `y' to overwrite\n";
    $resp = <STDIN>;
    chomp($resp);
    if($resp eq "y" || $resp eq "Y") 
    {
        print "Overwriting the file.\n";
    }
    else
    {
        exit;
    }
}

# Open source file and Destination file
open(INP,"<$inptagd") or die "could not open file ";
open(OP,">$chktokfl") or die "could not open file ";

# Initialise
$data = "";
$write = 0;
# Read lines from SOURCE - line by line
while(<INP>)
{
    # Print all tokens in angular braces to DESTINATION file
    while(/(<[<>s\s]*[^<>s\s]+[<>s\s]*>)/g)
    {
	$data = $1;
	print OP "$data\n";
	$write = 1;
    }
}

if($write == 0)		{ unlink "$chktokfl"; }

# Subroutine to print help message
sub help
{
    print "Usage: xml.pl [OPTIONS] DESTINATION SOURCE \n\n";
    print "This program checks if any non-contextual data in the form of xml tags still exists in the SOURCE file. It prints all tokens within angular braces into the DESTINATION file.\n\n";
    print "OPTIONS:\n\n";
    print "  --help             Prints the help message.\n";
    print "  --version          Prints the version number.\n\n";
}

sub usage
{
    print "Usage: xml.pl [OPTIONS] DESTINATION SOURCE\n";
    AskHelp();
}
# Message describing way to get help
sub AskHelp
{
    print "Type xml.pl --help for help.\n";
}
# function to output the version number
sub showVersion
{
    print STDERR "xml.pl      -        version 0.1\n";
    print STDERR "A component of posSenseval version 0.1\n";
    print STDERR "Copyright (C) 2000-2003, Saif Mohammad Ted Pedersen\n";
}

